==> 1.2025.316.6.tar.gz: OBJECTS/gen/chrome/browser/resources/actor_overlay/tsc/actor_overlay.mojom-webui.d.ts <==
import { mojo } from '//resources/mojo/mojo/public/js/bindings.js';
export type ActorOverlayPageHandlerFactoryPendingReceiverEndpoint = mojo.internal.interfaceSupport.Endpoint<ActorOverlayPageHandlerFactoryPendingReceiver>;
export declare class ActorOverlayPageHandlerFactoryPendingReceiver implements mojo.internal.interfaceSupport.PendingReceiver<ActorOverlayPageHandlerFactory> {
    handle: mojo.internal.interfaceSupport.Endpoint<ActorOverlayPageHandlerFactoryPendingReceiver>;
    constructor(handle: MojoHandle | ActorOverlayPageHandlerFactoryPendingReceiverEndpoint);
    bindInBrowser(scope?: string): void;
}
export interface ActorOverlayPageHandlerFactoryInterface {
    createPageHandler(page: ActorOverlayPageRemote, receiver: ActorOverlayPageHandlerPendingReceiver): void;
}
export declare class ActorOverlayPageHandlerFactoryRemote implements ActorOverlayPageHandlerFactoryInterface {
    private proxy;
    $: mojo.internal.interfaceSupport.InterfaceRemoteBaseWrapper<ActorOverlayPageHandlerFactoryPendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(handle?: MojoHandle | ActorOverlayPageHandlerFactoryPendingReceiverEndpoint);
    createPageHandler(page: ActorOverlayPageRemote, receiver: ActorOverlayPageHandlerPendingReceiver): void;
}
/**
 * An object which receives request messages for the ActorOverlayPageHandlerFactory
 * mojom interface. Must be constructed over an object which implements that
 * interface.
 */
export declare class ActorOverlayPageHandlerFactoryReceiver {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageHandlerFactoryRemote, ActorOverlayPageHandlerFactoryPendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(impl: ActorOverlayPageHandlerFactoryInterface);
}
export declare class ActorOverlayPageHandlerFactory {
    static get $interfaceName(): string;
    /**
     * Returns a remote for this interface which sends messages to the browser.
     * The browser must have an interface request binder registered for this
     * interface and accessible to the calling document's frame.
     */
    static getRemote(): ActorOverlayPageHandlerFactoryRemote;
}
/**
 * An object which receives request messages for the ActorOverlayPageHandlerFactory
 * mojom interface and dispatches them as callbacks. One callback receiver exists
 * on this object for each message defined in the mojom interface, and each
 * receiver can have any number of listeners added to it.
 */
export declare class ActorOverlayPageHandlerFactoryCallbackRouter {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageHandlerFactoryRemote, ActorOverlayPageHandlerFactoryPendingReceiver>;
    router_: mojo.internal.interfaceSupport.CallbackRouter;
    createPageHandler: mojo.internal.interfaceSupport.InterfaceCallbackReceiver;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor();
    /**
     * @param id An ID returned by a prior call to addListener.
     * @return True iff the identified listener was found and removed.
     */
    removeListener(id: number): boolean;
}
export type ActorOverlayPageHandlerPendingReceiverEndpoint = mojo.internal.interfaceSupport.Endpoint<ActorOverlayPageHandlerPendingReceiver>;
export declare class ActorOverlayPageHandlerPendingReceiver implements mojo.internal.interfaceSupport.PendingReceiver<ActorOverlayPageHandler> {
    handle: mojo.internal.interfaceSupport.Endpoint<ActorOverlayPageHandlerPendingReceiver>;
    constructor(handle: MojoHandle | ActorOverlayPageHandlerPendingReceiverEndpoint);
    bindInBrowser(scope?: string): void;
}
export interface ActorOverlayPageHandlerInterface {
    onHoverStatusChanged(isHovering: boolean): void;
}
export declare class ActorOverlayPageHandlerRemote implements ActorOverlayPageHandlerInterface {
    private proxy;
    $: mojo.internal.interfaceSupport.InterfaceRemoteBaseWrapper<ActorOverlayPageHandlerPendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(handle?: MojoHandle | ActorOverlayPageHandlerPendingReceiverEndpoint);
    onHoverStatusChanged(isHovering: boolean): void;
}
/**
 * An object which receives request messages for the ActorOverlayPageHandler
 * mojom interface. Must be constructed over an object which implements that
 * interface.
 */
export declare class ActorOverlayPageHandlerReceiver {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageHandlerRemote, ActorOverlayPageHandlerPendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(impl: ActorOverlayPageHandlerInterface);
}
export declare class ActorOverlayPageHandler {
    static get $interfaceName(): string;
    /**
     * Returns a remote for this interface which sends messages to the browser.
     * The browser must have an interface request binder registered for this
     * interface and accessible to the calling document's frame.
     */
    static getRemote(): ActorOverlayPageHandlerRemote;
}
/**
 * An object which receives request messages for the ActorOverlayPageHandler
 * mojom interface and dispatches them as callbacks. One callback receiver exists
 * on this object for each message defined in the mojom interface, and each
 * receiver can have any number of listeners added to it.
 */
export declare class ActorOverlayPageHandlerCallbackRouter {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageHandlerRemote, ActorOverlayPageHandlerPendingReceiver>;
    router_: mojo.internal.interfaceSupport.CallbackRouter;
    onHoverStatusChanged: mojo.internal.interfaceSupport.InterfaceCallbackReceiver;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor();
    /**
     * @param id An ID returned by a prior call to addListener.
     * @return True iff the identified listener was found and removed.
     */
    removeListener(id: number): boolean;
}
export type ActorOverlayPagePendingReceiverEndpoint = mojo.internal.interfaceSupport.Endpoint<ActorOverlayPagePendingReceiver>;
export declare class ActorOverlayPagePendingReceiver implements mojo.internal.interfaceSupport.PendingReceiver<ActorOverlayPage> {
    handle: mojo.internal.interfaceSupport.Endpoint<ActorOverlayPagePendingReceiver>;
    constructor(handle: MojoHandle | ActorOverlayPagePendingReceiverEndpoint);
    bindInBrowser(scope?: string): void;
}
export interface ActorOverlayPageInterface {
    setScrimBackground(isVisible: boolean): void;
}
export declare class ActorOverlayPageRemote implements ActorOverlayPageInterface {
    private proxy;
    $: mojo.internal.interfaceSupport.InterfaceRemoteBaseWrapper<ActorOverlayPagePendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(handle?: MojoHandle | ActorOverlayPagePendingReceiverEndpoint);
    setScrimBackground(isVisible: boolean): void;
}
/**
 * An object which receives request messages for the ActorOverlayPage
 * mojom interface. Must be constructed over an object which implements that
 * interface.
 */
export declare class ActorOverlayPageReceiver {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageRemote, ActorOverlayPagePendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(impl: ActorOverlayPageInterface);
}
export declare class ActorOverlayPage {
    static get $interfaceName(): string;
    /**
     * Returns a remote for this interface which sends messages to the browser.
     * The browser must have an interface request binder registered for this
     * interface and accessible to the calling document's frame.
     */
    static getRemote(): ActorOverlayPageRemote;
}
/**
 * An object which receives request messages for the ActorOverlayPage
 * mojom interface and dispatches them as callbacks. One callback receiver exists
 * on this object for each message defined in the mojom interface, and each
 * receiver can have any number of listeners added to it.
 */
export declare class ActorOverlayPageCallbackRouter {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageRemote, ActorOverlayPagePendingReceiver>;
    router_: mojo.internal.interfaceSupport.CallbackRouter;
    setScrimBackground: mojo.internal.interfaceSupport.InterfaceCallbackReceiver;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor();
    /**
     * @param id An ID returned by a prior call to addListener.
     * @return True iff the identified listener was found and removed.
     */
    removeListener(id: number): boolean;
}
export declare const ActorOverlayPageHandlerFactory_CreatePageHandler_ParamsSpec: {
    $: mojo.internal.MojomType;
};
export declare const ActorOverlayPageHandler_OnHoverStatusChanged_ParamsSpec: {
    $: mojo.internal.MojomType;
};
export declare const ActorOverlayPage_SetScrimBackground_ParamsSpec: {
    $: mojo.internal.MojomType;
};
export interface ActorOverlayPageHandlerFactory_CreatePageHandler_ParamsMojoType {
    page: ActorOverlayPageRemote;
    receiver: ActorOverlayPageHandlerPendingReceiver;
}
export type ActorOverlayPageHandlerFactory_CreatePageHandler_Params = ActorOverlayPageHandlerFactory_CreatePageHandler_ParamsMojoType;
export interface ActorOverlayPageHandler_OnHoverStatusChanged_ParamsMojoType {
    isHovering: boolean;
}
export type ActorOverlayPageHandler_OnHoverStatusChanged_Params = ActorOverlayPageHandler_OnHoverStatusChanged_ParamsMojoType;
export interface ActorOverlayPage_SetScrimBackground_ParamsMojoType {
    isVisible: boolean;
}
export type ActorOverlayPage_SetScrimBackground_Params = ActorOverlayPage_SetScrimBackground_ParamsMojoType;

==> 1.2025.323.6.tar.gz: OBJECTS/gen/chrome/browser/resources/actor_overlay/tsc/actor_overlay.mojom-webui.d.ts <==
import { mojo } from '//resources/mojo/mojo/public/js/bindings.js';
export type ActorOverlayPageHandlerFactoryPendingReceiverEndpoint = mojo.internal.interfaceSupport.Endpoint<ActorOverlayPageHandlerFactoryPendingReceiver>;
export declare class ActorOverlayPageHandlerFactoryPendingReceiver implements mojo.internal.interfaceSupport.PendingReceiver<ActorOverlayPageHandlerFactory> {
    handle: mojo.internal.interfaceSupport.Endpoint<ActorOverlayPageHandlerFactoryPendingReceiver>;
    constructor(handle: MojoHandle | ActorOverlayPageHandlerFactoryPendingReceiverEndpoint);
    bindInBrowser(scope?: string): void;
}
export interface ActorOverlayPageHandlerFactoryInterface {
    createPageHandler(page: ActorOverlayPageRemote, receiver: ActorOverlayPageHandlerPendingReceiver): void;
}
export declare class ActorOverlayPageHandlerFactoryRemote implements ActorOverlayPageHandlerFactoryInterface {
    private proxy;
    $: mojo.internal.interfaceSupport.InterfaceRemoteBaseWrapper<ActorOverlayPageHandlerFactoryPendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(handle?: MojoHandle | ActorOverlayPageHandlerFactoryPendingReceiverEndpoint);
    createPageHandler(page: ActorOverlayPageRemote, receiver: ActorOverlayPageHandlerPendingReceiver): void;
}
/**
 * An object which receives request messages for the ActorOverlayPageHandlerFactory
 * mojom interface. Must be constructed over an object which implements that
 * interface.
 */
export declare class ActorOverlayPageHandlerFactoryReceiver {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageHandlerFactoryRemote, ActorOverlayPageHandlerFactoryPendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(impl: ActorOverlayPageHandlerFactoryInterface);
}
export declare class ActorOverlayPageHandlerFactory {
    static get $interfaceName(): string;
    /**
     * Returns a remote for this interface which sends messages to the browser.
     * The browser must have an interface request binder registered for this
     * interface and accessible to the calling document's frame.
     */
    static getRemote(): ActorOverlayPageHandlerFactoryRemote;
}
/**
 * An object which receives request messages for the ActorOverlayPageHandlerFactory
 * mojom interface and dispatches them as callbacks. One callback receiver exists
 * on this object for each message defined in the mojom interface, and each
 * receiver can have any number of listeners added to it.
 */
export declare class ActorOverlayPageHandlerFactoryCallbackRouter {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageHandlerFactoryRemote, ActorOverlayPageHandlerFactoryPendingReceiver>;
    router_: mojo.internal.interfaceSupport.CallbackRouter;
    createPageHandler: mojo.internal.interfaceSupport.InterfaceCallbackReceiver;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor();
    /**
     * @param id An ID returned by a prior call to addListener.
     * @return True iff the identified listener was found and removed.
     */
    removeListener(id: number): boolean;
}
export type ActorOverlayPageHandlerPendingReceiverEndpoint = mojo.internal.interfaceSupport.Endpoint<ActorOverlayPageHandlerPendingReceiver>;
export declare class ActorOverlayPageHandlerPendingReceiver implements mojo.internal.interfaceSupport.PendingReceiver<ActorOverlayPageHandler> {
    handle: mojo.internal.interfaceSupport.Endpoint<ActorOverlayPageHandlerPendingReceiver>;
    constructor(handle: MojoHandle | ActorOverlayPageHandlerPendingReceiverEndpoint);
    bindInBrowser(scope?: string): void;
}
export interface ActorOverlayPageHandlerInterface {
    onHoverStatusChanged(isHovering: boolean): void;
    getCurrentBorderGlowVisibility(): Promise<{
        isVisible: boolean;
    }>;
}
export declare class ActorOverlayPageHandlerRemote implements ActorOverlayPageHandlerInterface {
    private proxy;
    $: mojo.internal.interfaceSupport.InterfaceRemoteBaseWrapper<ActorOverlayPageHandlerPendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(handle?: MojoHandle | ActorOverlayPageHandlerPendingReceiverEndpoint);
    onHoverStatusChanged(isHovering: boolean): void;
    getCurrentBorderGlowVisibility(): Promise<{
        isVisible: boolean;
    }>;
}
/**
 * An object which receives request messages for the ActorOverlayPageHandler
 * mojom interface. Must be constructed over an object which implements that
 * interface.
 */
export declare class ActorOverlayPageHandlerReceiver {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageHandlerRemote, ActorOverlayPageHandlerPendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(impl: ActorOverlayPageHandlerInterface);
}
export declare class ActorOverlayPageHandler {
    static get $interfaceName(): string;
    /**
     * Returns a remote for this interface which sends messages to the browser.
     * The browser must have an interface request binder registered for this
     * interface and accessible to the calling document's frame.
     */
    static getRemote(): ActorOverlayPageHandlerRemote;
}
/**
 * An object which receives request messages for the ActorOverlayPageHandler
 * mojom interface and dispatches them as callbacks. One callback receiver exists
 * on this object for each message defined in the mojom interface, and each
 * receiver can have any number of listeners added to it.
 */
export declare class ActorOverlayPageHandlerCallbackRouter {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageHandlerRemote, ActorOverlayPageHandlerPendingReceiver>;
    router_: mojo.internal.interfaceSupport.CallbackRouter;
    onHoverStatusChanged: mojo.internal.interfaceSupport.InterfaceCallbackReceiver;
    getCurrentBorderGlowVisibility: mojo.internal.interfaceSupport.InterfaceCallbackReceiver;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor();
    /**
     * @param id An ID returned by a prior call to addListener.
     * @return True iff the identified listener was found and removed.
     */
    removeListener(id: number): boolean;
}
export type ActorOverlayPagePendingReceiverEndpoint = mojo.internal.interfaceSupport.Endpoint<ActorOverlayPagePendingReceiver>;
export declare class ActorOverlayPagePendingReceiver implements mojo.internal.interfaceSupport.PendingReceiver<ActorOverlayPage> {
    handle: mojo.internal.interfaceSupport.Endpoint<ActorOverlayPagePendingReceiver>;
    constructor(handle: MojoHandle | ActorOverlayPagePendingReceiverEndpoint);
    bindInBrowser(scope?: string): void;
}
export interface ActorOverlayPageInterface {
    setScrimBackground(isVisible: boolean): void;
    setBorderGlowVisibility(isVisible: boolean): void;
}
export declare class ActorOverlayPageRemote implements ActorOverlayPageInterface {
    private proxy;
    $: mojo.internal.interfaceSupport.InterfaceRemoteBaseWrapper<ActorOverlayPagePendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(handle?: MojoHandle | ActorOverlayPagePendingReceiverEndpoint);
    setScrimBackground(isVisible: boolean): void;
    setBorderGlowVisibility(isVisible: boolean): void;
}
/**
 * An object which receives request messages for the ActorOverlayPage
 * mojom interface. Must be constructed over an object which implements that
 * interface.
 */
export declare class ActorOverlayPageReceiver {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageRemote, ActorOverlayPagePendingReceiver>;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor(impl: ActorOverlayPageInterface);
}
export declare class ActorOverlayPage {
    static get $interfaceName(): string;
    /**
     * Returns a remote for this interface which sends messages to the browser.
     * The browser must have an interface request binder registered for this
     * interface and accessible to the calling document's frame.
     */
    static getRemote(): ActorOverlayPageRemote;
}
/**
 * An object which receives request messages for the ActorOverlayPage
 * mojom interface and dispatches them as callbacks. One callback receiver exists
 * on this object for each message defined in the mojom interface, and each
 * receiver can have any number of listeners added to it.
 */
export declare class ActorOverlayPageCallbackRouter {
    private helper_internal_;
    $: mojo.internal.interfaceSupport.InterfaceReceiverHelper<ActorOverlayPageRemote, ActorOverlayPagePendingReceiver>;
    router_: mojo.internal.interfaceSupport.CallbackRouter;
    setScrimBackground: mojo.internal.interfaceSupport.InterfaceCallbackReceiver;
    setBorderGlowVisibility: mojo.internal.interfaceSupport.InterfaceCallbackReceiver;
    onConnectionError: mojo.internal.interfaceSupport.ConnectionErrorEventRouter;
    constructor();
    /**
     * @param id An ID returned by a prior call to addListener.
     * @return True iff the identified listener was found and removed.
     */
    removeListener(id: number): boolean;
}
export declare const ActorOverlayPageHandlerFactory_CreatePageHandler_ParamsSpec: {
    $: mojo.internal.MojomType;
};
export declare const ActorOverlayPageHandler_OnHoverStatusChanged_ParamsSpec: {
    $: mojo.internal.MojomType;
};
export declare const ActorOverlayPageHandler_GetCurrentBorderGlowVisibility_ParamsSpec: {
    $: mojo.internal.MojomType;
};
export declare const ActorOverlayPageHandler_GetCurrentBorderGlowVisibility_ResponseParamsSpec: {
    $: mojo.internal.MojomType;
};
export declare const ActorOverlayPage_SetScrimBackground_ParamsSpec: {
    $: mojo.internal.MojomType;
};
export declare const ActorOverlayPage_SetBorderGlowVisibility_ParamsSpec: {
    $: mojo.internal.MojomType;
};
export interface ActorOverlayPageHandlerFactory_CreatePageHandler_ParamsMojoType {
    page: ActorOverlayPageRemote;
    receiver: ActorOverlayPageHandlerPendingReceiver;
}
export type ActorOverlayPageHandlerFactory_CreatePageHandler_Params = ActorOverlayPageHandlerFactory_CreatePageHandler_ParamsMojoType;
export interface ActorOverlayPageHandler_OnHoverStatusChanged_ParamsMojoType {
    isHovering: boolean;
}
export type ActorOverlayPageHandler_OnHoverStatusChanged_Params = ActorOverlayPageHandler_OnHoverStatusChanged_ParamsMojoType;
export interface ActorOverlayPageHandler_GetCurrentBorderGlowVisibility_ParamsMojoType {
}
export type ActorOverlayPageHandler_GetCurrentBorderGlowVisibility_Params = ActorOverlayPageHandler_GetCurrentBorderGlowVisibility_ParamsMojoType;
export interface ActorOverlayPageHandler_GetCurrentBorderGlowVisibility_ResponseParamsMojoType {
    isVisible: boolean;
}
export type ActorOverlayPageHandler_GetCurrentBorderGlowVisibility_ResponseParams = ActorOverlayPageHandler_GetCurrentBorderGlowVisibility_ResponseParamsMojoType;
export interface ActorOverlayPage_SetScrimBackground_ParamsMojoType {
    isVisible: boolean;
}
export type ActorOverlayPage_SetScrimBackground_Params = ActorOverlayPage_SetScrimBackground_ParamsMojoType;
export interface ActorOverlayPage_SetBorderGlowVisibility_ParamsMojoType {
    isVisible: boolean;
}
export type ActorOverlayPage_SetBorderGlowVisibility_Params = ActorOverlayPage_SetBorderGlowVisibility_ParamsMojoType;
